summaryrefslogtreecommitdiffstats
path: root/Guard/AbstractGuardAuthenticator.php
diff options
context:
space:
mode:
Diffstat (limited to 'Guard/AbstractGuardAuthenticator.php')
-rw-r--r--Guard/AbstractGuardAuthenticator.php10
1 files changed, 5 insertions, 5 deletions
diff --git a/Guard/AbstractGuardAuthenticator.php b/Guard/AbstractGuardAuthenticator.php
index ebd09bb..647cb02 100644
--- a/Guard/AbstractGuardAuthenticator.php
+++ b/Guard/AbstractGuardAuthenticator.php
@@ -3,26 +3,26 @@
namespace Symfony\Component\Security\Guard;
use Symfony\Component\Security\Core\User\UserInterface;
-use Symfony\Component\Security\Guard\Token\GenericGuardToken;
+use Symfony\Component\Security\Guard\Token\PostAuthenticationGuardToken;
/**
* An optional base class that creates a GenericGuardToken for you
*
* @author Ryan Weaver <weaverryan@gmail.com>
*/
abstract class AbstractGuardAuthenticator implements GuardAuthenticatorInterface
{
/**
* Shortcut to create a GenericGuardToken for you, if you don't really
* care about which authenticated token you're using
*
* @param UserInterface $user
* @param string $providerKey
- * @return GenericGuardToken
+ * @return PostAuthenticationGuardToken
*/
public function createAuthenticatedToken(UserInterface $user, $providerKey)
{
- return new GenericGuardToken(
+ return new PostAuthenticationGuardToken(
$user,
$providerKey,
$user->getRoles()
@@ -3,26 +3,26 @@
/**
- * An optional base class that creates a GenericGuardToken for you
+ * An optional base class that creates a PostAuthenticationGuardToken for you
*
* @author Ryan Weaver <weaverryan@gmail.com>
@@ -3,26 +3,26 @@
{
/**
- * Shortcut to create a GenericGuardToken for you, if you don't really
+ * Shortcut to create a PostAuthenticationGuardToken for you, if you don't really
* care about which authenticated token you're using
*